@@ -6,5 +6,7 @@ from .linear0 import Linear0
 from .custom_fun import CustomFun
 from .ml_call_options import MLCallOptions
 from .box_integral import BoxIntegral
-from .sobol_indices import SobolIndices,SensitivityIndices
+from .sensitivity_indices import SobolIndices,SensitivityIndices
 from .ishigami import Ishigami
+from .bayesian_lr_coeffs import BayesianLRCoeffs
+from .um_bridge_wrapper import UMBridgeWrapper
\ No newline at end of file
