@@ -2,11 +2,12 @@ from ._stopping_criterion import StoppingCriterion
 from ..accumulate_data import MeanVarDataRep
 from ..discrete_distribution._discrete_distribution import DiscreteDistribution
 from ..discrete_distribution import Lattice,DigitalNetB2,Halton
+from ..discrete_distribution._discrete_distribution import LD
 from ..true_measure import Gaussian,Uniform
 from ..integrand import Keister,BoxIntegral,CustomFun
 from ..util import MaxSamplesWarning, NotYetImplemented, ParameterWarning, ParameterError
 from numpy import *
-from scipy.stats import norm
+from scipy.stats import t
 from time import time
 import warnings
 
@@ -23,13 +24,9 @@ class CubQMCCLT(StoppingCriterion):
     >>> data
     MeanVarDataRep (AccumulateData Object)
         solution        1.380
-        indv_error      6.92e-04
-        ci_low          1.380
-        ci_high         1.381
-        ci_comb_low     1.380
-        ci_comb_high    1.381
-        flags_comb      0
-        flags_indv      0
+        comb_bound_low  1.380
+        comb_bound_high 1.381
+        comb_flags      1
         n_total         2^(12)
         n               2^(12)
         n_rep           2^(8)
@@ -63,13 +60,9 @@ class CubQMCCLT(StoppingCriterion):
     >>> data
     MeanVarDataRep (AccumulateData Object)
         solution        [1.19  0.961]
-        indv_error      [0.001 0.001]
-        ci_low          [1.19 0.96]
-        ci_high         [1.191 0.961]
-        ci_comb_low     [1.19 0.96]
-        ci_comb_high    [1.191 0.961]
-        flags_comb      [False False]
-        flags_indv      [False False]
+        comb_bound_low  [1.19 0.96]
+        comb_bound_high [1.191 0.961]
+        comb_flags      [ True  True]
         n_total         2^(21)
         n               [2097152.    8192.]
         n_rep           [131072.    512.]
@@ -102,26 +95,18 @@ class CubQMCCLT(StoppingCriterion):
     >>> cf = CustomFun(
     ...     true_measure = Uniform(DigitalNetB2(6,seed=7)),
     ...     g = lambda x,compute_flags=None: (2*arange(1,7)*x).reshape(-1,2,3),
-    ...     dprime = (2,3))
+    ...     dimension_indv = (2,3))
     >>> sol,data = CubQMCCLT(cf,abs_tol=1e-4).integrate()
     >>> data
     MeanVarDataRep (AccumulateData Object)
         solution        [[1. 2. 3.]
                         [4. 5. 6.]]
-        indv_error      [[2.484e-05 0.000e+00 0.000e+00]
-                        [5.708e-06 2.178e-10 0.000e+00]]
-        ci_low          [[1. 2. 3.]
+        comb_bound_low  [[1. 2. 3.]
                         [4. 5. 6.]]
-        ci_high         [[1. 2. 3.]
+        comb_bound_high [[1. 2. 3.]
                         [4. 5. 6.]]
-        ci_comb_low     [[1. 2. 3.]
-                        [4. 5. 6.]]
-        ci_comb_high    [[1. 2. 3.]
-                        [4. 5. 6.]]
-        flags_comb      [[False False False]
-                        [False False False]]
-        flags_indv      [[False False False]
-                        [False False False]]
+        comb_flags      [[ True  True  True]
+                        [ True  True  True]]
         n_total         2^(14)
         n               [[ 4096.  4096.  4096.]
                         [16384.  4096.  4096.]]
@@ -156,9 +141,9 @@ class CubQMCCLT(StoppingCriterion):
         Args:
             integrand (Integrand): an instance of Integrand
             inflate (float): inflation factor when estimating variance
-            alpha (float): significance level for confidence interval
-            abs_tol (float): absolute error tolerance
-            rel_tol (float): relative error tolerance
+            alpha (ndarray): significance level for confidence interval
+            abs_tol (ndarray): absolute error tolerance
+            rel_tol (ndarray): relative error tolerance
             n_max (int): maximum number of samples
             replications (int): number of replications
             error_fun: function taking in the approximate solution vector, 
@@ -176,8 +161,7 @@ class CubQMCCLT(StoppingCriterion):
         self.rel_tol = rel_tol
         self.n_init = float(n_init)
         self.n_max = float(n_max)
-        self.alpha = float(alpha)
-        self.z_star = -norm.ppf(self.alpha / 2)
+        self.alpha = alpha
         self.inflate = float(inflate)
         self.replications = int(replications)
         self.error_fun = error_fun
@@ -185,58 +169,57 @@ class CubQMCCLT(StoppingCriterion):
         self.integrand = integrand
         self.true_measure = self.integrand.true_measure
         self.discrete_distrib = self.integrand.discrete_distrib
-        self.dprime = self.integrand.dprime
+        self.d_indv = self.integrand.d_indv
         self.d = self.discrete_distrib.d
-        # Verify Compliant Construction
-        allowed_levels = ["single"]
-        allowed_distribs = [Lattice,DigitalNetB2,Halton]
-        allow_vectorized_integrals = True
-        super(CubQMCCLT,self).__init__(allowed_levels, allowed_distribs, allow_vectorized_integrals)
+        super(CubQMCCLT,self).__init__(allowed_levels=["single"], allowed_distribs=[LD], allow_vectorized_integrals=True)
         if not self.discrete_distrib.randomize:
             raise ParameterError("CLTRep requires distribution to have randomize=True")
+        self.alphas_indv,identity_dependency = self._compute_indv_alphas(full(self.integrand.d_comb,self.alpha))
+        self.t_star = -t.ppf(self.alphas_indv/2,df=self.replications-1)
          
     def integrate(self):
         """ See abstract method. """
         t_start = time()
-        self.datum = empty(self.dprime,dtype=object)
-        for j in ndindex(self.dprime):
-            self.datum[j] = MeanVarDataRep(self.z_star,self.inflate,self.replications)
+        self.datum = empty(self.d_indv,dtype=object)
+        for j in ndindex(self.d_indv):
+            self.datum[j] = MeanVarDataRep(self.t_star[j],self.inflate,self.replications)
         self.data = MeanVarDataRep.__new__(MeanVarDataRep)
-        self.data.flags_indv = tile(True,self.dprime)
+        self.data.flags_indv = tile(False,self.d_indv)
+        self.data.compute_flags = tile(True,self.d_indv)
         self.data.rep_distribs = self.integrand.discrete_distrib.spawn(s=self.replications)
-        self.data.n_rep = tile(self.n_init,self.dprime)
+        self.data.n_rep = tile(self.n_init,self.d_indv)
         self.data.n_min_rep = 0
-        self.data.ci_low = tile(-inf,self.dprime)
-        self.data.ci_high = tile(inf,self.dprime)
-        self.data.solution_indv = tile(nan,self.dprime)
+        self.data.indv_bound_low = tile(-inf,self.d_indv)
+        self.data.indv_bound_high = tile(inf,self.d_indv)
+        self.data.solution_indv = tile(nan,self.d_indv)
         self.data.solution = nan
         self.data.xfull = empty((0,self.d))
-        self.data.yfull = empty((0,)+self.dprime)
+        self.data.yfull = empty((0,)+self.d_indv)
         while True:
             n_min = self.data.n_min_rep
             n_max = int(self.data.n_rep.max())
             n = int(n_max-n_min)
             xnext = vstack([self.data.rep_distribs[r].gen_samples(n_min=n_min,n_max=n_max) for r in range(self.replications)])
-            ynext = self.integrand.f(xnext,compute_flags=self.data.flags_indv)
-            for j in ndindex(self.dprime):
-                if not self.data.flags_indv[j]: continue
+            ynext = self.integrand.f(xnext,compute_flags=self.data.compute_flags)
+            for j in ndindex(self.d_indv):
+                if self.data.flags_indv[j]: continue
                 yj = ynext[(slice(None),)+j].reshape((n,self.replications),order='f')
-                self.data.solution_indv[j],self.data.ci_low[j],self.data.ci_high[j] = self.datum[j].update_data(yj)
+                self.data.solution_indv[j],self.data.indv_bound_low[j],self.data.indv_bound_high[j] = self.datum[j].update_data(yj)
             self.data.xfull = vstack((self.data.xfull,xnext))
             self.data.yfull = vstack((self.data.yfull,ynext))
-            self.data.indv_error = (self.data.ci_high-self.data.ci_low)/2
-            self.data.ci_comb_low,self.data.ci_comb_high,self.data.violated = self.integrand.bound_fun(self.data.ci_low,self.data.ci_high)
-            error_low = self.error_fun(self.data.ci_comb_low,self.abs_tol,self.rel_tol)
-            error_high = self.error_fun(self.data.ci_comb_high,self.abs_tol,self.rel_tol)
-            self.data.solution = 1/2*(self.data.ci_comb_low+self.data.ci_comb_high+error_low-error_high)
-            rem_error_low = abs(self.data.ci_comb_low-self.data.solution)-error_low
-            rem_error_high = abs(self.data.ci_comb_high-self.data.solution)-error_high
-            self.data.flags_comb = maximum(rem_error_low,rem_error_high)>=0
-            self.data.flags_comb |= self.data.violated
-            self.data.flags_indv = self.integrand.dependency(self.data.flags_comb)
+            self.data.comb_bound_low,self.data.comb_bound_high = self.integrand.bound_fun(self.data.indv_bound_low,self.data.indv_bound_high)
+            self.abs_tols,self.rel_tols = full_like(self.data.comb_bound_low,self.abs_tol),full_like(self.data.comb_bound_low,self.rel_tol)
+            fidxs = isfinite(self.data.comb_bound_low)&isfinite(self.data.comb_bound_high)
+            slow,shigh,abs_tols,rel_tols = self.data.comb_bound_low[fidxs],self.data.comb_bound_high[fidxs],self.abs_tols[fidxs],self.rel_tols[fidxs]
+            self.data.solution = tile(nan,self.data.comb_bound_low.shape)
+            self.data.solution[fidxs] = 1/2*(slow+shigh+self.error_fun(slow,abs_tols,rel_tols)-self.error_fun(shigh,abs_tols,rel_tols))
+            self.data.comb_flags = tile(False,self.data.comb_bound_low.shape)
+            self.data.comb_flags[fidxs] = (shigh-slow) <= (self.error_fun(slow,abs_tols,rel_tols)+self.error_fun(shigh,abs_tols,rel_tols))
+            self.data.flags_indv = self.integrand.dependency(self.data.comb_flags)
+            self.data.compute_flags = ~self.data.flags_indv
             self.data.n = self.replications*self.data.n_rep
             self.data.n_total = self.data.n.max()
-            if sum(self.data.flags_indv)==0:
+            if sum(self.data.compute_flags)==0:
                 break # sufficiently estimated
             elif 2*self.data.n_total>self.n_max:
                 warning_s = """
@@ -249,20 +232,16 @@ class CubQMCCLT(StoppingCriterion):
                 break
             else:
                 self.data.n_min_rep = n_max
-                self.data.n_rep += self.data.n_rep*self.data.flags_indv # double sample size
+                self.data.n_rep += self.data.n_rep*(self.data.compute_flags) # double sample size
         self.data.integrand = self.integrand
         self.data.true_measure = self.true_measure
         self.data.discrete_distrib = self.discrete_distrib
         self.data.stopping_crit = self
         self.data.parameters = [
             'solution',
-            'indv_error',
-            'ci_low',
-            'ci_high',
-            'ci_comb_low',
-            'ci_comb_high',
-            'flags_comb',
-            'flags_indv',
+            'comb_bound_low',
+            'comb_bound_high',
+            'comb_flags',
             'n_total',
             'n',
             'n_rep',
@@ -280,4 +259,6 @@ class CubQMCCLT(StoppingCriterion):
             rel_tol (float): relative tolerance. Reset if supplied, ignored if not. 
         """
         if abs_tol != None: self.abs_tol = abs_tol
-        if rel_tol != None: self.rel_tol = rel_tol
\ No newline at end of file
+        if rel_tol != None: self.rel_tol = rel_tol
+
+class CubQMCRep(CubQMCCLT): pass
